@@ -9,7 +9,11 @@ from e2e_cli.loadbalancer.lb_routing import LBRouting
 from e2e_cli.node.node_routing import NodeRouting
 from e2e_cli.bucket_store.bucket_routing import BucketRouting
 from e2e_cli.dbaas.dbaas_routing import DBaaSRouting
-
+from e2e_cli.image.image_routing import ImageRouting
+from e2e_cli.auto_scaling.autoscaling_routing import autoscaling_Routing
+from e2e_cli.cdn.cdn_routing import cdn_Routing
+from e2e_cli.vpc.vpc_routing import vpc_Routing
+from e2e_cli.volumes.volumes_routing import volumes_Routing
 
 class CommandsRouting:
     def __init__(self, arguments):
@@ -32,9 +36,7 @@ class CommandsRouting:
             try:
                 NodeRouting(self.arguments).route()
             except Exception as e:
-                        Py_version_manager.py_print("Oops!! An error occurred for more info, type : debug")
-                        if(Py_version_manager.py_input("debug/exit ?? ").lower()=="debug"):
-                                traceback.print_exc()
+                        Checks.manage_exception(e)
 
         elif self.arguments.command == "lb":
             try: 
@@ -60,3 +62,38 @@ class CommandsRouting:
                         if(Py_version_manager.py_input("debug/exit ?? ").lower()=="debug"):
                                 traceback.print_exc()
                             # action_on_exception(e, self.arguments.alias, traceback.print_exc())
+
+        elif self.arguments.command == "image":
+            try:
+                ImageRouting(self.arguments).route()
+            except Exception as e:
+                        Checks.manage_exception(e)
+                        # action_on_exception(e, self.arguments.alias, traceback.print_exc())   
+
+        elif self.arguments.command == "autoscaling":
+            try:
+                autoscaling_Routing(self.arguments).route()
+            except Exception as e:
+                        Checks.manage_exception(e)
+                        # action_on_exception(e, self.arguments.alias, traceback.print_exc())   
+        
+        elif self.arguments.command == "cdn":
+            try:
+                cdn_Routing(self.arguments).route()
+            except Exception as e:
+                        Checks.manage_exception(e)
+                        # action_on_exception(e, self.arguments.alias, traceback.print_exc()) 
+
+        elif self.arguments.command == "vpc":
+            try:
+                vpc_Routing(self.arguments).route()
+            except Exception as e:
+                        Checks.manage_exception(e)
+                        # action_on_exception(e, self.arguments.alias, traceback.print_exc())  
+
+        elif self.arguments.command == "volumes":
+            try:
+                volumes_Routing(self.arguments).route()
+            except Exception as e:
+                        Checks.manage_exception(e)
+                        # action_on_exception(e, self.arguments.alias, traceback.print_exc())  
\ No newline at end of file
