@@ -20,7 +20,7 @@ def option_check(alias):
 
 class AliasServices:
     def __init__(self, alias):
-        self.alias = alias
+        self.alias = option_check(alias)
 
     def get_api_credentials(self):
         file= os.path.expanduser("~") + '/.E2E_CLI/config.json'
